Struct google_run1::api::ConfigMapEnvSource[][src]

pub struct ConfigMapEnvSource {
    pub local_object_reference: Option<LocalObjectReference>,
    pub name: Option<String>,
    pub optional: Option<bool>,
}

Cloud Run fully managed: not supported Cloud Run for Anthos: supported ConfigMapEnvSource selects a ConfigMap to populate the environment variables with. The contents of the target ConfigMap’s Data field will represent the key-value pairs as environment variables.

This type is not used in any activity, and only used as part of another schema.

Fields

local_object_reference: Option<LocalObjectReference>

This field should not be used directly as it is meant to be inlined directly into the message. Use the “name” field instead.

name: Option<String>

Cloud Run fully managed: not supported Cloud Run for Anthos: supported The ConfigMap to select from.

optional: Option<bool>

(Optional) Cloud Run fully managed: not supported Cloud Run for Anthos: supported Specify whether the ConfigMap must be defined