Struct google_run1::api::Configuration[][src]

pub struct Configuration {
    pub api_version: Option<String>,
    pub kind: Option<String>,
    pub metadata: Option<ObjectMeta>,
    pub spec: Option<ConfigurationSpec>,
    pub status: Option<ConfigurationStatus>,
}

Configuration represents the “floating HEAD” of a linear history of Revisions, and optionally how the containers those revisions reference are built. Users create new Revisions by updating the Configuration’s spec. The “latest created” revision’s name is available under status, as is the “latest ready” revision’s name. See also: https://github.com/knative/serving/blob/master/docs/spec/overview.md#configuration

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

api_version: Option<String>

The API version for this call such as “serving.knative.dev/v1”.

kind: Option<String>

The kind of resource, in this case always “Configuration”.

metadata: Option<ObjectMeta>

Metadata associated with this Configuration, including name, namespace, labels, and annotations.

spec: Option<ConfigurationSpec>

Spec holds the desired state of the Configuration (from the client).

status: Option<ConfigurationStatus>

Status communicates the observed state of the Configuration (from the controller).