Struct google_run1::api::ConfigurationSpec[][src]

pub struct ConfigurationSpec {
    pub template: Option<RevisionTemplate>,
}

ConfigurationSpec holds the desired state of the Configuration (from the client).

This type is not used in any activity, and only used as part of another schema.

Fields

template: Option<RevisionTemplate>

Template holds the latest specification for the Revision to be stamped out.