Struct google_run1::api::ConfigurationStatus[][src]

pub struct ConfigurationStatus {
    pub conditions: Option<Vec<GoogleCloudRunV1Condition>>,
    pub latest_created_revision_name: Option<String>,
    pub latest_ready_revision_name: Option<String>,
    pub observed_generation: Option<i32>,
}

ConfigurationStatus communicates the observed state of the Configuration (from the controller).

This type is not used in any activity, and only used as part of another schema.

Fields

conditions: Option<Vec<GoogleCloudRunV1Condition>>

Conditions communicates information about ongoing/complete reconciliation processes that bring the “spec” inline with the observed state of the world.

latest_created_revision_name: Option<String>

LatestCreatedRevisionName is the last revision that was created from this Configuration. It might not be ready yet, for that use LatestReadyRevisionName.

latest_ready_revision_name: Option<String>

LatestReadyRevisionName holds the name of the latest Revision stamped out from this Configuration that has had its “Ready” condition become “True”.

observed_generation: Option<i32>

ObservedGeneration is the ‘Generation’ of the Configuration that was last processed by the controller. The observed generation is updated even if the controller failed to process the spec and create the Revision. Clients polling for completed reconciliation should poll until observedGeneration = metadata.generation, and the Ready condition’s status is True or False.