Struct google_run1::api::DomainMappingStatus [−][src]
The current state of the Domain Mapping.
This type is not used in any activity, and only used as part of another schema.
Fields
conditions: Option<Vec<GoogleCloudRunV1Condition>>Array of observed DomainMappingConditions, indicating the current state of the DomainMapping.
mapped_route_name: Option<String>The name of the route that the mapping currently points to.
observed_generation: Option<i32>ObservedGeneration is the ‘Generation’ of the DomainMapping that was last processed by the controller. Clients polling for completed reconciliation should poll until observedGeneration = metadata.generation and the Ready condition’s status is True or False.
resource_records: Option<Vec<ResourceRecord>>The resource records required to configure this domain mapping. These records must be added to the domain’s DNS configuration in order to serve the application via this domain mapping.
url: Option<String>Cloud Run fully managed: not supported Cloud Run on GKE: supported Holds the URL that will serve the traffic of the DomainMapping. +optional