Struct google_run1::api::EnvFromSource [−][src]
Cloud Run fully managed: not supported Cloud Run for Anthos: supported EnvFromSource represents the source of a set of ConfigMaps
This type is not used in any activity, and only used as part of another schema.
Fields
config_map_ref: Option<ConfigMapEnvSource>(Optional) Cloud Run fully managed: not supported Cloud Run for Anthos: supported The ConfigMap to select from
prefix: Option<String>(Optional) Cloud Run fully managed: not supported Cloud Run for Anthos: supported An optional identifier to prepend to each key in the ConfigMap. Must be a C_IDENTIFIER.
secret_ref: Option<SecretEnvSource>(Optional) Cloud Run fully managed: not supported Cloud Run for Anthos: supported The Secret to select from