pub struct Execution {
pub api_version: Option<String>,
pub kind: Option<String>,
pub metadata: Option<ObjectMeta>,
pub spec: Option<ExecutionSpec>,
pub status: Option<ExecutionStatus>,
}Expand description
Execution represents the configuration of a single execution. An execution is an immutable resource that references a container image which is run to completion.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- executions cancel namespaces (response)
- executions get namespaces (response)
- jobs run namespaces (response)
Fields
api_version: Option<String>Optional. APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values.
kind: Option<String>Optional. Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase.
metadata: Option<ObjectMeta>Optional. Standard object’s metadata.
spec: Option<ExecutionSpec>Optional. Specification of the desired behavior of an execution.
status: Option<ExecutionStatus>Output only. Current status of an execution.