pub struct ExecutionSpec {
pub parallelism: Option<i32>,
pub task_count: Option<i32>,
pub template: Option<TaskTemplateSpec>,
}Expand description
ExecutionSpec describes how the execution will look.
This type is not used in any activity, and only used as part of another schema.
Fields
parallelism: Option<i32>Optional. Specifies the maximum desired number of tasks the execution should run at given time. When the job is run, if this field is 0 or unset, the maximum possible value will be used for that execution. The actual number of tasks running in steady state will be less than this number when there are fewer tasks waiting to be completed, i.e. when the work left to do is less than max parallelism.
task_count: Option<i32>Optional. Specifies the desired number of tasks the execution should run. Setting to 1 means that parallelism is limited to 1 and the success of that task signals the success of the execution. Defaults to 1.
template: Option<TaskTemplateSpec>Optional. The template used to create tasks for this execution.