pub struct ExecutionStatus {
pub cancelled_count: Option<i32>,
pub completion_time: Option<DateTime<Utc>>,
pub conditions: Option<Vec<GoogleCloudRunV1Condition>>,
pub failed_count: Option<i32>,
pub log_uri: Option<String>,
pub observed_generation: Option<i32>,
pub retried_count: Option<i32>,
pub running_count: Option<i32>,
pub start_time: Option<DateTime<Utc>>,
pub succeeded_count: Option<i32>,
}Expand description
ExecutionStatus represents the current state of an Execution.
This type is not used in any activity, and only used as part of another schema.
Fields
cancelled_count: Option<i32>Optional. The number of tasks which reached phase Cancelled.
completion_time: Option<DateTime<Utc>>Optional. Represents the time that the execution was completed. It is not guaranteed to be set in happens-before order across separate operations. It is represented in RFC3339 form and is in UTC. +optional
conditions: Option<Vec<GoogleCloudRunV1Condition>>Optional. Conditions communicate information about ongoing/complete reconciliation processes that bring the “spec” inline with the observed state of the world. Execution-specific conditions include: * ResourcesAvailable: True when underlying resources have been provisioned. * Started: True when the execution has started to execute. * Completed: True when the execution has succeeded. False when the execution has failed.
failed_count: Option<i32>Optional. The number of tasks which reached phase Failed.
log_uri: Option<String>Optional. URI where logs for this execution can be found in Cloud Console.
observed_generation: Option<i32>Optional. The ‘generation’ of the execution that was last processed by the controller.
retried_count: Option<i32>Optional. The number of tasks which have retried at least once.
running_count: Option<i32>Optional. The number of actively running tasks.
start_time: Option<DateTime<Utc>>Optional. Represents the time that the execution started to run. It is not guaranteed to be set in happens-before order across separate operations. It is represented in RFC3339 form and is in UTC.
succeeded_count: Option<i32>Optional. The number of tasks which reached phase Succeeded.