pub struct ExecutionTemplateSpec {
pub metadata: Option<ObjectMeta>,
pub spec: Option<ExecutionSpec>,
}Expand description
ExecutionTemplateSpec describes the metadata and spec an Execution should have when created from a job.
This type is not used in any activity, and only used as part of another schema.
Fields
metadata: Option<ObjectMeta>Optional. Optional metadata for this Execution, including labels and annotations. The following annotation keys set properties of the created execution: * run.googleapis.com/cloudsql-instances sets Cloud SQL connections. Multiple values should be comma separated. * run.googleapis.com/vpc-access-connector sets a Serverless VPC Access connector. * run.googleapis.com/vpc-access-egress sets VPC egress. Supported values are all-traffic, all (deprecated), and private-ranges-only. all-traffic and all provide the same functionality. all is deprecated but will continue to be supported. Prefer all-traffic.
spec: Option<ExecutionSpec>Required. ExecutionSpec holds the desired configuration for executions of this job.