pub struct GoogleCloudRunV1Condition {
pub last_transition_time: Option<DateTime<Utc>>,
pub message: Option<String>,
pub reason: Option<String>,
pub severity: Option<String>,
pub status: Option<String>,
pub type_: Option<String>,
}Expand description
Conditions show the status of reconciliation progress on a given resource. Most resource use a top-level condition type “Ready” or “Completed” to show overall status with other conditions to checkpoint each stage of reconciliation. Note that if metadata.Generation does not equal status.ObservedGeneration, the conditions shown may not be relevant for the current spec.
This type is not used in any activity, and only used as part of another schema.
Fields
last_transition_time: Option<DateTime<Utc>>Optional. Last time the condition transitioned from one status to another.
message: Option<String>Optional. Human readable message indicating details about the current status.
reason: Option<String>Optional. One-word CamelCase reason for the condition’s last transition. These are intended to be stable, unique values which the client may use to trigger error handling logic, whereas messages which may be changed later by the server.
severity: Option<String>Optional. How to interpret this condition. One of Error, Warning, or Info. Conditions of severity Info do not contribute to resource readiness.
status: Option<String>Status of the condition, one of True, False, Unknown.
type_: Option<String>type is used to communicate the status of the reconciliation process. Types common to all resources include: * “Ready” or “Completed”: True when the Resource is ready.