Struct google_run1::api::ListConfigurationsResponse[][src]

pub struct ListConfigurationsResponse {
    pub api_version: Option<String>,
    pub items: Option<Vec<Configuration>>,
    pub kind: Option<String>,
    pub metadata: Option<ListMeta>,
    pub unreachable: Option<Vec<String>>,
}

ListConfigurationsResponse is a list of Configuration resources.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

api_version: Option<String>

The API version for this call such as “serving.knative.dev/v1”.

items: Option<Vec<Configuration>>

List of Configurations.

kind: Option<String>

The kind of this resource, in this case “ConfigurationList”.

metadata: Option<ListMeta>

Metadata associated with this Configuration list.

unreachable: Option<Vec<String>>

Locations that could not be reached.