Struct google_run1::api::ListDomainMappingsResponse[][src]

pub struct ListDomainMappingsResponse {
    pub api_version: Option<String>,
    pub items: Option<Vec<DomainMapping>>,
    pub kind: Option<String>,
    pub metadata: Option<ListMeta>,
    pub unreachable: Option<Vec<String>>,
}

ListDomainMappingsResponse is a list of DomainMapping resources.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

api_version: Option<String>

The API version for this call such as “domains.cloudrun.com/v1”.

items: Option<Vec<DomainMapping>>

List of DomainMappings.

kind: Option<String>

The kind of this resource, in this case “DomainMappingList”.

metadata: Option<ListMeta>

Metadata associated with this DomainMapping list.

unreachable: Option<Vec<String>>

Locations that could not be reached.