Struct google_run1::api::ListServicesResponse[][src]

pub struct ListServicesResponse {
    pub api_version: Option<String>,
    pub items: Option<Vec<Service>>,
    pub kind: Option<String>,
    pub metadata: Option<ListMeta>,
    pub unreachable: Option<Vec<String>>,
}

A list of Service resources.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

api_version: Option<String>

The API version for this call such as “serving.knative.dev/v1”.

items: Option<Vec<Service>>

List of Services.

kind: Option<String>

The kind of this resource, in this case “ServiceList”.

metadata: Option<ListMeta>

Metadata associated with this Service list.

unreachable: Option<Vec<String>>

Locations that could not be reached.