Struct google_run1::api::LocalObjectReference[][src]

pub struct LocalObjectReference {
    pub name: Option<String>,
}

Cloud Run fully managed: not supported Cloud Run for Anthos: supported LocalObjectReference contains enough information to let you locate the referenced object inside the same namespace.

This type is not used in any activity, and only used as part of another schema.

Fields

name: Option<String>

(Optional) Cloud Run fully managed: not supported Cloud Run for Anthos: supported Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names