Struct google_run1::api::OwnerReference[][src]

pub struct OwnerReference {
    pub api_version: Option<String>,
    pub block_owner_deletion: Option<bool>,
    pub controller: Option<bool>,
    pub kind: Option<String>,
    pub name: Option<String>,
    pub uid: Option<String>,
}

OwnerReference contains enough information to let you identify an owning object. Currently, an owning object must be in the same namespace, so there is no namespace field.

This type is not used in any activity, and only used as part of another schema.

Fields

api_version: Option<String>

API version of the referent.

block_owner_deletion: Option<bool>

If true, AND if the owner has the “foregroundDeletion” finalizer, then the owner cannot be deleted from the key-value store until this reference is removed. Defaults to false. To set this field, a user needs “delete” permission of the owner, otherwise 422 (Unprocessable Entity) will be returned. +optional

controller: Option<bool>

If true, this reference points to the managing controller. +optional

kind: Option<String>

Kind of the referent. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds

name: Option<String>

Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names

uid: Option<String>

UID of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#uids