pub struct ResourceRequirements {
pub limits: Option<HashMap<String, String>>,
pub requests: Option<HashMap<String, String>>,
}Expand description
ResourceRequirements describes the compute resource requirements.
This type is not used in any activity, and only used as part of another schema.
Fields
limits: Option<HashMap<String, String>>Limits describes the maximum amount of compute resources allowed. Only ‘cpu’, ‘memory’ and ‘nvidia.com/gpu’ keys are supported. * For supported ‘cpu’ values, go to https://cloud.google.com/run/docs/configuring/cpu. * For supported ‘memory’ values and syntax, go to https://cloud.google.com/run/docs/configuring/memory-limits. * The only supported ‘nvidia.com/gpu’ value is ‘1’.
requests: Option<HashMap<String, String>>Requests describes the minimum amount of compute resources required. Only cpu and memory are supported. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. * For supported ‘cpu’ values, go to https://cloud.google.com/run/docs/configuring/cpu. * For supported ‘memory’ values and syntax, go to https://cloud.google.com/run/docs/configuring/memory-limits