pub struct Revision {
pub api_version: Option<String>,
pub kind: Option<String>,
pub metadata: Option<ObjectMeta>,
pub spec: Option<RevisionSpec>,
pub status: Option<RevisionStatus>,
}Expand description
Revision is an immutable snapshot of code and configuration. A revision references a container image. Revisions are created by updates to a Configuration. See also: https://github.com/knative/specs/blob/main/specs/serving/overview.md#revision
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- revisions get namespaces (response)
- locations revisions get projects (response)
Fields
api_version: Option<String>The API version for this call such as “serving.knative.dev/v1”.
kind: Option<String>The kind of this resource, in this case “Revision”.
metadata: Option<ObjectMeta>Metadata associated with this Revision, including name, namespace, labels, and annotations.
spec: Option<RevisionSpec>Spec holds the desired state of the Revision (from the client).
status: Option<RevisionStatus>Status communicates the observed state of the Revision (from the controller).