Struct google_run1::api::RevisionSpec[][src]

pub struct RevisionSpec {
    pub container_concurrency: Option<i32>,
    pub containers: Option<Vec<Container>>,
    pub service_account_name: Option<String>,
    pub timeout_seconds: Option<i32>,
    pub volumes: Option<Vec<Volume>>,
}

RevisionSpec holds the desired state of the Revision (from the client).

This type is not used in any activity, and only used as part of another schema.

Fields

container_concurrency: Option<i32>

(Optional) ContainerConcurrency specifies the maximum allowed in-flight (concurrent) requests per container instance of the Revision. Cloud Run fully managed: supported, defaults to 80 Cloud Run for Anthos: supported, defaults to 0, which means concurrency to the application is not limited, and the system decides the target concurrency for the autoscaler.

containers: Option<Vec<Container>>

Containers holds the single container that defines the unit of execution for this Revision. In the context of a Revision, we disallow a number of fields on this Container, including: name and lifecycle. In Cloud Run, only a single container may be provided. The runtime contract is documented here: https://github.com/knative/serving/blob/master/docs/runtime-contract.md

service_account_name: Option<String>

Email address of the IAM service account associated with the revision of the service. The service account represents the identity of the running revision, and determines what permissions the revision has. If not provided, the revision will use the project’s default service account.

timeout_seconds: Option<i32>

TimeoutSeconds holds the max duration the instance is allowed for responding to a request. Cloud Run fully managed: defaults to 300 seconds (5 minutes). Maximum allowed value is 900 seconds (15 minutes). Cloud Run for Anthos: defaults to 300 seconds (5 minutes). Maximum allowed value is configurable by the cluster operator.

volumes: Option<Vec<Volume>>

no description provided