pub struct RevisionStatus {
pub conditions: Option<Vec<GoogleCloudRunV1Condition>>,
pub desired_replicas: Option<i32>,
pub image_digest: Option<String>,
pub log_url: Option<String>,
pub observed_generation: Option<i32>,
pub service_name: Option<String>,
}Expand description
RevisionStatus communicates the observed state of the Revision (from the controller).
This type is not used in any activity, and only used as part of another schema.
Fields
conditions: Option<Vec<GoogleCloudRunV1Condition>>Conditions communicate information about ongoing/complete reconciliation processes that bring the “spec” inline with the observed state of the world. As a Revision is being prepared, it will incrementally update conditions. Revision-specific conditions include: * ResourcesAvailable: True when underlying resources have been provisioned. * ContainerHealthy: True when the Revision readiness check completes. * Active: True when the Revision may receive traffic.
desired_replicas: Option<i32>Output only. The configured number of instances running this revision. For Cloud Run, this only includes instances provisioned using the minScale annotation. It does not include instances created by autoscaling.
image_digest: Option<String>ImageDigest holds the resolved digest for the image specified within .Spec.Container.Image. The digest is resolved during the creation of Revision. This field holds the digest value regardless of whether a tag or digest was originally specified in the Container object.
log_url: Option<String>Optional. Specifies the generated logging url for this particular revision based on the revision url template specified in the controller’s config.
observed_generation: Option<i32>ObservedGeneration is the ‘Generation’ of the Revision that was last processed by the controller. Clients polling for completed reconciliation should poll until observedGeneration = metadata.generation, and the Ready condition’s status is True or False.
service_name: Option<String>Not currently used by Cloud Run.