Struct google_run1::api::RevisionTemplate[][src]

pub struct RevisionTemplate {
    pub metadata: Option<ObjectMeta>,
    pub spec: Option<RevisionSpec>,
}

RevisionTemplateSpec describes the data a revision should have when created from a template. Based on: https://github.com/kubernetes/api/blob/e771f807/core/v1/types.go#L3179-L3190

This type is not used in any activity, and only used as part of another schema.

Fields

metadata: Option<ObjectMeta>

Optional metadata for this Revision, including labels and annotations. Name will be generated by the Configuration. The following annotation keys set properties of the created revision: * autoscaling.knative.dev/minScale sets the minimum number of instances. * autoscaling.knative.dev/maxScale sets the maximum number of instances. * run.googleapis.com/cloudsql-instances sets Cloud SQL connections. Multiple values should be comma separated. * run.googleapis.com/vpc-access-connector sets a Serverless VPC Access connector. * run.googleapis.com/vpc-access-egress sets VPC egress. Supported values are all and private-ranges-only.

spec: Option<RevisionSpec>

RevisionSpec holds the desired state of the Revision (from the client).