pub struct RunJobRequest {
pub overrides: Option<Overrides>,
}Expand description
Request message for creating a new execution of a job.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- jobs run namespaces (request)
Fields
overrides: Option<Overrides>Optional. Overrides existing job configuration for one specific new job execution only, using the specified values to update the job configuration for the new execution.