Struct google_run1::api::ServiceSpec[][src]

pub struct ServiceSpec {
    pub template: Option<RevisionTemplate>,
    pub traffic: Option<Vec<TrafficTarget>>,
}

ServiceSpec holds the desired state of the Route (from the client), which is used to manipulate the underlying Route and Configuration(s).

This type is not used in any activity, and only used as part of another schema.

Fields

template: Option<RevisionTemplate>

Template holds the latest specification for the Revision to be stamped out.

traffic: Option<Vec<TrafficTarget>>

Traffic specifies how to distribute traffic over a collection of Knative Revisions and Configurations.