pub struct ServiceStatus {
pub address: Option<Addressable>,
pub conditions: Option<Vec<GoogleCloudRunV1Condition>>,
pub latest_created_revision_name: Option<String>,
pub latest_ready_revision_name: Option<String>,
pub observed_generation: Option<i32>,
pub traffic: Option<Vec<TrafficTarget>>,
pub url: Option<String>,
}Expand description
The current state of the Service. Output only.
This type is not used in any activity, and only used as part of another schema.
Fields
address: Option<Addressable>Similar to url, information on where the service is available on HTTP.
conditions: Option<Vec<GoogleCloudRunV1Condition>>Conditions communicate information about ongoing/complete reconciliation processes that bring the spec inline with the observed state of the world. Service-specific conditions include: * ConfigurationsReady: True when the underlying Configuration is ready. * RoutesReady: True when the underlying Route is ready. * Ready: True when all underlying resources are ready.
latest_created_revision_name: Option<String>Name of the last revision that was created from this Service’s Configuration. It might not be ready yet, for that use LatestReadyRevisionName.
latest_ready_revision_name: Option<String>Name of the latest Revision from this Service’s Configuration that has had its Ready condition become True.
observed_generation: Option<i32>Returns the generation last seen by the system. Clients polling for completed reconciliation should poll until observedGeneration = metadata.generation and the Ready condition’s status is True or False.
traffic: Option<Vec<TrafficTarget>>Holds the configured traffic distribution. These entries will always contain RevisionName references. When ConfigurationName appears in the spec, this will hold the LatestReadyRevisionName that we last observed.
url: Option<String>URL that will distribute traffic over the provided traffic targets. It generally has the form https://{route-hash}-{project-hash}-{cluster-level-suffix}.a.run.app