Struct google_run1::api::Status[][src]

pub struct Status {
    pub code: Option<i32>,
    pub details: Option<StatusDetails>,
    pub message: Option<String>,
    pub metadata: Option<ListMeta>,
    pub reason: Option<String>,
    pub status: Option<String>,
}

Status is a return value for calls that don’t return other objects

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

code: Option<i32>

Suggested HTTP return code for this status, 0 if not set. +optional

details: Option<StatusDetails>

Extended data associated with the reason. Each reason may define its own extended details. This field is optional and the data returned is not guaranteed to conform to any schema except that defined by the reason type. +optional

message: Option<String>

A human-readable description of the status of this operation. +optional

metadata: Option<ListMeta>

Standard list metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds +optional

reason: Option<String>

A machine-readable description of why this operation is in the “Failure” status. If this value is empty there is no information available. A Reason clarifies an HTTP status code but does not override it. +optional

status: Option<String>

Status of the operation. One of: “Success” or “Failure”. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status +optional