Struct google_run1::api::TCPSocketAction [−][src]
Cloud Run fully managed: not supported Cloud Run for Anthos: supported TCPSocketAction describes an action based on opening a socket
This type is not used in any activity, and only used as part of another schema.
Fields
host: Option<String>(Optional) Cloud Run fully managed: not supported Cloud Run for Anthos: supported Optional: Host name to connect to, defaults to the pod IP.
port: Option<i32>Cloud Run fully managed: not supported Cloud Run for Anthos: supported Number or name of the port to access on the container. Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME. This field is currently limited to integer types only because of proto’s inability to properly support the IntOrString golang type.