Struct google_run1::api::Volume [−][src]
Cloud Run fully managed: not supported Cloud Run for Anthos: supported Volume represents a named volume in a container.
This type is not used in any activity, and only used as part of another schema.
Fields
config_map: Option<ConfigMapVolumeSource>Cloud Run fully managed: not supported Cloud Run for Anthos: supported
name: Option<String>Cloud Run fully managed: supported Cloud Run for Anthos: supported Volume’s name.
secret: Option<SecretVolumeSource>Cloud Run fully managed: supported Cloud Run for Anthos: supported