Struct google_run1::api::VolumeMount [−][src]
Cloud Run fully managed: not supported Cloud Run for Anthos: supported VolumeMount describes a mounting of a Volume within a container.
This type is not used in any activity, and only used as part of another schema.
Fields
mount_path: Option<String>Cloud Run fully managed: supported Cloud Run for Anthos: supported Path within the container at which the volume should be mounted. Must not contain ‘:’.
name: Option<String>Cloud Run fully managed: supported Cloud Run for Anthos: supported This must match the Name of a Volume.
read_only: Option<bool>(Optional) Cloud Run fully managed: supported Cloud Run for Anthos: supported Only true is accepted. Defaults to true.
sub_path: Option<String>(Optional) Cloud Run fully managed: not supported Cloud Run for Anthos: supported Path within the volume from which the container’s volume should be mounted. Defaults to “” (volume’s root).