Struct google_run1::api::DomainMapping [−][src]
Resource to hold the state and status of a user’s domain mapping. NOTE: This resource is currently in Beta.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- domainmappings create namespaces (request|response)
- domainmappings get namespaces (response)
- locations domainmappings create projects (request|response)
- locations domainmappings get projects (response)
Fields
api_version: Option<String>The API version for this call such as “domains.cloudrun.com/v1”.
kind: Option<String>The kind of resource, in this case “DomainMapping”.
metadata: Option<ObjectMeta>Metadata associated with this BuildTemplate.
spec: Option<DomainMappingSpec>The spec for this DomainMapping.
status: Option<DomainMappingStatus>The current status of the DomainMapping.