Struct google_run1::api::ListDomainMappingsResponse [−][src]
ListDomainMappingsResponse is a list of DomainMapping resources.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- domainmappings list namespaces (response)
- locations domainmappings list projects (response)
Fields
api_version: Option<String>The API version for this call such as “domains.cloudrun.com/v1”.
items: Option<Vec<DomainMapping>>List of DomainMappings.
kind: Option<String>The kind of this resource, in this case “DomainMappingList”.
metadata: Option<ListMeta>Metadata associated with this DomainMapping list.
unreachable: Option<Vec<String>>Locations that could not be reached.