pub struct RevisionSpec {
pub container_concurrency: Option<i32>,
pub containers: Option<Vec<Container>>,
pub enable_service_links: Option<bool>,
pub image_pull_secrets: Option<Vec<LocalObjectReference>>,
pub node_selector: Option<HashMap<String, String>>,
pub runtime_class_name: Option<String>,
pub service_account_name: Option<String>,
pub timeout_seconds: Option<i32>,
pub volumes: Option<Vec<Volume>>,
}Expand description
RevisionSpec holds the desired state of the Revision (from the client).
This type is not used in any activity, and only used as part of another schema.
Fields
container_concurrency: Option<i32>ContainerConcurrency specifies the maximum allowed in-flight (concurrent) requests per container instance of the Revision. If not specified or 0, defaults to 80 when requested CPU >= 1 and defaults to 1 when requested CPU < 1.
containers: Option<Vec<Container>>Required. Containers holds the list which define the units of execution for this Revision. In the context of a Revision, we disallow a number of fields on this Container, including: name and lifecycle.
enable_service_links: Option<bool>Not supported by Cloud Run.
image_pull_secrets: Option<Vec<LocalObjectReference>>Not supported by Cloud Run.
node_selector: Option<HashMap<String, String>>Optional. The Node Selector configuration. Map of selector key to a value which matches a node.
runtime_class_name: Option<String>Optional. Runtime. Leave unset for default.
service_account_name: Option<String>Email address of the IAM service account associated with the revision of the service. The service account represents the identity of the running revision, and determines what permissions the revision has. If not provided, the revision will use the project’s default service account.
timeout_seconds: Option<i32>Optional. TimeoutSeconds holds the max duration the instance is allowed for responding to a request. Cloud Run: defaults to 300 seconds (5 minutes). Maximum allowed value is 3600 seconds (1 hour).
volumes: Option<Vec<Volume>>no description provided