pub struct RevisionTemplate {
pub metadata: Option<ObjectMeta>,
pub spec: Option<RevisionSpec>,
}Expand description
RevisionTemplateSpec describes the data a revision should have when created from a template.
This type is not used in any activity, and only used as part of another schema.
Fields
metadata: Option<ObjectMeta>Optional metadata for this Revision, including labels and annotations. Name will be generated by the Configuration. The following annotation keys set properties of the created revision: * autoscaling.knative.dev/minScale sets the minimum number of instances. * autoscaling.knative.dev/maxScale sets the maximum number of instances. * run.googleapis.com/cloudsql-instances sets Cloud SQL connections. Multiple values should be comma separated. * run.googleapis.com/health-check-disabled: if true, deploy-time startup probes will not run for this revision. * run.googleapis.com/vpc-access-connector sets a Serverless VPC Access connector. * run.googleapis.com/vpc-access-egress sets VPC egress. Supported values are all-traffic, all (deprecated), and private-ranges-only. all-traffic and all provide the same functionality. all is deprecated but will continue to be supported. Prefer all-traffic.
spec: Option<RevisionSpec>RevisionSpec holds the desired state of the Revision (from the client).