pub struct Route {
pub api_version: Option<String>,
pub kind: Option<String>,
pub metadata: Option<ObjectMeta>,
pub spec: Option<RouteSpec>,
pub status: Option<RouteStatus>,
}Expand description
Route is responsible for configuring ingress over a collection of Revisions. Some of the Revisions a Route distributes traffic over may be specified by referencing the Configuration responsible for creating them; in these cases the Route is additionally responsible for monitoring the Configuration for “latest ready” revision changes, and smoothly rolling out latest revisions. Cloud Run currently supports referencing a single Configuration to automatically deploy the “latest ready” Revision from that Configuration.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- routes get namespaces (response)
- locations routes get projects (response)
Fields
api_version: Option<String>The API version for this call such as “serving.knative.dev/v1”.
kind: Option<String>The kind of this resource, in this case always “Route”.
metadata: Option<ObjectMeta>Metadata associated with this Route, including name, namespace, labels, and annotations.
spec: Option<RouteSpec>Spec holds the desired state of the Route (from the client).
status: Option<RouteStatus>Status communicates the observed state of the Route (from the controller).