pub struct RouteStatus {
pub address: Option<Addressable>,
pub conditions: Option<Vec<GoogleCloudRunV1Condition>>,
pub observed_generation: Option<i32>,
pub traffic: Option<Vec<TrafficTarget>>,
pub url: Option<String>,
}Expand description
RouteStatus communicates the observed state of the Route (from the controller).
This type is not used in any activity, and only used as part of another schema.
Fields
address: Option<Addressable>Similar to url, information on where the service is available on HTTP.
conditions: Option<Vec<GoogleCloudRunV1Condition>>Conditions communicates information about ongoing/complete reconciliation processes that bring the “spec” inline with the observed state of the world.
observed_generation: Option<i32>ObservedGeneration is the ‘Generation’ of the Route that was last processed by the controller. Clients polling for completed reconciliation should poll until observedGeneration = metadata.generation and the Ready condition’s status is True or False. Note that providing a TrafficTarget that has latest_revision=True will result in a Route that does not increment either its metadata.generation or its observedGeneration, as new “latest ready” revisions from the Configuration are processed without an update to the Route’s spec.
traffic: Option<Vec<TrafficTarget>>Traffic holds the configured traffic distribution. These entries will always contain RevisionName references. When ConfigurationName appears in the spec, this will hold the LatestReadyRevisionName that was last observed.
url: Option<String>URL holds the url that will distribute traffic over the provided traffic targets. It generally has the form: https://{route-hash}-{project-hash}-{cluster-level-suffix}.a.run.app