Struct google_run1::api::Service [−][src]
Service acts as a top-level container that manages a set of Routes and Configurations which implement a network service. Service exists to provide a singular abstraction which can be access controlled, reasoned about, and which encapsulates software lifecycle decisions such as rollout policy and team resource ownership. Service acts only as an orchestrator of the underlying Routes and Configurations (much as a kubernetes Deployment orchestrates ReplicaSets). The Service’s controller will track the statuses of its owned Configuration and Route, reflecting their statuses and conditions as its own. See also: https://github.com/knative/serving/blob/master/docs/spec/overview.md#service
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- services create namespaces (request|response)
- services get namespaces (response)
- services replace service namespaces (request|response)
- locations services create projects (request|response)
- locations services get projects (response)
- locations services replace service projects (request|response)
Fields
api_version: Option<String>The API version for this call such as “serving.knative.dev/v1”.
kind: Option<String>The kind of resource, in this case “Service”.
metadata: Option<ObjectMeta>Metadata associated with this Service, including name, namespace, labels, and annotations. Cloud Run (fully managed) uses the following annotation keys to configure features on a Service: * run.googleapis.com/ingress sets the ingress settings for the Service. See the ingress settings documentation for details on configuring ingress settings. * run.googleapis.com/ingress-status is output-only and contains the currently active ingress settings for the Service. run.googleapis.com/ingress-status may differ from run.googleapis.com/ingress while the system is processing a change to run.googleapis.com/ingress or if the system failed to process a change to run.googleapis.com/ingress. When the system has processed all changes successfully run.googleapis.com/ingress-status and run.googleapis.com/ingress are equal.
spec: Option<ServiceSpec>Spec holds the desired state of the Service (from the client).
status: Option<ServiceStatus>Status communicates the observed state of the Service (from the controller).