pub struct Service {
pub api_version: Option<String>,
pub kind: Option<String>,
pub metadata: Option<ObjectMeta>,
pub spec: Option<ServiceSpec>,
pub status: Option<ServiceStatus>,
}Expand description
Service acts as a top-level container that manages a set of Routes and Configurations which implement a network service. Service exists to provide a singular abstraction which can be access controlled, reasoned about, and which encapsulates software lifecycle decisions such as rollout policy and team resource ownership. Service acts only as an orchestrator of the underlying Routes and Configurations (much as a kubernetes Deployment orchestrates ReplicaSets). The Service’s controller will track the statuses of its owned Configuration and Route, reflecting their statuses and conditions as its own.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- services create namespaces (request|response)
- services get namespaces (response)
- services replace service namespaces (request|response)
- locations services create projects (request|response)
- locations services get projects (response)
- locations services replace service projects (request|response)
Fields
api_version: Option<String>The API version for this call. It must be “serving.knative.dev/v1”.
kind: Option<String>The kind of resource. It must be “Service”.
metadata: Option<ObjectMeta>Metadata associated with this Service, including name, namespace, labels, and annotations. In Cloud Run, annotations with ‘run.googleapis.com/’ and ‘autoscaling.knative.dev’ are restricted, and the accepted annotations will be different depending on the resource type. The following Cloud Run-specific annotations are accepted in Service.metadata.annotations. * run.googleapis.com/binary-authorization-breakglass * run.googleapis.com/binary-authorization * run.googleapis.com/client-name * run.googleapis.com/custom-audiences * run.googleapis.com/default-url-disabled * run.googleapis.com/description * run.googleapis.com/gc-traffic-tags * run.googleapis.com/ingress * run.googleapis.com/ingress sets the ingress settings for the Service. See the ingress settings documentation for details on configuring ingress settings. * run.googleapis.com/ingress-status is output-only and contains the currently active ingress settings for the Service. run.googleapis.com/ingress-status may differ from run.googleapis.com/ingress while the system is processing a change to run.googleapis.com/ingress or if the system failed to process a change to run.googleapis.com/ingress. When the system has processed all changes successfully run.googleapis.com/ingress-status and run.googleapis.com/ingress are equal.
spec: Option<ServiceSpec>Holds the desired state of the Service (from the client).
status: Option<ServiceStatus>Communicates the system-controlled state of the Service.