pub struct Status {
pub code: Option<i32>,
pub details: Option<StatusDetails>,
pub message: Option<String>,
pub metadata: Option<ListMeta>,
pub reason: Option<String>,
pub status: Option<String>,
}Expand description
Status is a return value for calls that don’t return other objects.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- domainmappings delete namespaces (response)
- executions delete namespaces (response)
- jobs delete namespaces (response)
- revisions delete namespaces (response)
- services delete namespaces (response)
- workerpools delete namespaces (response)
- locations domainmappings delete projects (response)
- locations revisions delete projects (response)
- locations services delete projects (response)
Fields
code: Option<i32>Suggested HTTP return code for this status, 0 if not set.
details: Option<StatusDetails>Extended data associated with the reason. Each reason may define its own extended details. This field is optional and the data returned is not guaranteed to conform to any schema except that defined by the reason type.
message: Option<String>A human-readable description of the status of this operation.
metadata: Option<ListMeta>Standard list metadata.
reason: Option<String>A machine-readable description of why this operation is in the “Failure” status. If this value is empty there is no information available. A Reason clarifies an HTTP status code but does not override it.
status: Option<String>Status of the operation. One of: “Success” or “Failure”.