pub struct TrafficTarget {
pub configuration_name: Option<String>,
pub latest_revision: Option<bool>,
pub percent: Option<i32>,
pub revision_name: Option<String>,
pub tag: Option<String>,
pub url: Option<String>,
}Expand description
TrafficTarget holds a single entry of the routing table for a Route.
This type is not used in any activity, and only used as part of another schema.
Fields
configuration_name: Option<String>[Deprecated] Not supported in Cloud Run. It must be empty.
latest_revision: Option<bool>Uses the “status.latestReadyRevisionName” of the Service to determine the traffic target. When it changes, traffic will automatically migrate from the prior “latest ready” revision to the new one. This field must be false if RevisionName is set. This field defaults to true otherwise. If the field is set to true on Status, this means that the Revision was resolved from the Service’s latest ready revision.
percent: Option<i32>Percent specifies percent of the traffic to this Revision or Configuration. This defaults to zero if unspecified.
revision_name: Option<String>Points this traffic target to a specific Revision. This field is mutually exclusive with latest_revision.
tag: Option<String>Tag is used to expose a dedicated url for referencing this target exclusively.
url: Option<String>Output only. URL displays the URL for accessing tagged traffic targets. URL is displayed in status, and is disallowed on spec. URL must contain a scheme (e.g. https://) and a hostname, but may not contain anything else (e.g. basic auth, url path, etc.)